==> react-molecule-select-1.60.0.tgz: package/lib/components/MultipleSelection.js <==
import { useState } from 'react';
import { inputTypes } from '@s-ui/react-atom-input';
import MoleculeDropdownList from '@s-ui/react-molecule-dropdown-list';
import MoleculeInputTags from '@s-ui/react-molecule-input-tags';
import { useDropdown } from '../config.js';
import MoleculeInputSelect from './MoleculeInputSelect.js';
import Search from './Search.js';
import { jsx as _jsx } from "react/jsx-runtime";
import { Fragment as _Fragment } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
function removeDuplicateTags(tags) {
  var tagsSet = new Set();
  tags.forEach(function (tag) {
    return tagsSet.add(tag);
  });
  return Array.from(tagsSet).filter(Boolean);
}
function keepSelectedTagsIfRemovedFromDOM(optionsData, values) {
  return removeDuplicateTags([].concat(values.map(function (value) {
    return optionsData[value];
  }), values));
}
var MoleculeSelectFieldMultiSelection = function MoleculeSelectFieldMultiSelection(props) {
  /* eslint-disable react/prop-types */
  var children = props.children,
    isOpen = props.isOpen,
    onToggle = props.onToggle,
    onChange = props.onChange,
    iconArrowDown = props.iconArrowDown,
    iconCloseTag = props.iconCloseTag,
    refMoleculeSelect = props.refMoleculeSelect,
    values = props.value,
    placeholder = props.placeholder,
    keysSelection = props.keysSelection,
    id = props.id,
    size = props.size,
    required = props.required,
    _props$optionsData = props.optionsData,
    optionsData = _props$optionsData === void 0 ? {} : _props$optionsData,
    selectSize = props.selectSize,
    tabIndex = props.tabIndex,
    maxTags = props.maxTags;
  var tags = keepSelectedTagsIfRemovedFromDOM(optionsData, values);
  var _useState = useState(false),
    focusedFirstOption = _useState[0],
    setFocusedFirstOption = _useState[1];
  var _useDropdown = useDropdown(),
    hasSearch = _useDropdown.hasSearch,
    isFirstOptionFocused = _useDropdown.isFirstOptionFocused,
    inputSearch = _useDropdown.inputSearch;
  var handleMultiSelection = function handleMultiSelection(ev, _ref) {
    var valueOptionSelected = _ref.value;
    var handleToggle = function handleToggle(ev) {
      var key = ev.key;
      var isKeySelection = keysSelection.includes(key);
      if (ev.key !== undefined && !isKeySelection) onToggle(ev, {
        isOpen: false
      });
    };
    var isValueSelectedAlreadySelected = function isValueSelectedAlreadySelected() {
      return values.includes(valueOptionSelected);
    };
    var removeFromValues = function removeFromValues() {
      return values.filter(function (value) {
        return value !== valueOptionSelected;
      });
    };
    var addToValues = function addToValues() {
      return [].concat(values, [valueOptionSelected]);
    };
    var isFull = function isFull() {
      return maxTags && (tags == null ? void 0 : tags.length) >= maxTags;
    };
    if (isValueSelectedAlreadySelected()) {
      onChange(ev, {
        value: removeFromValues()
      });
    } else if (!isFull()) {
      onChange(ev, {
        value: addToValues()
      });
    }
    handleToggle(ev);
  };
  var handleChangeTags = function handleChangeTags(ev, _ref2) {
    var value = _ref2.tags;
    onChange(ev, {
      value: value
    });
    refMoleculeSelect.current.focus();
  };
  var handleKeyDown = function handleKeyDown(ev) {
    if (isFirstOptionFocused()) {
      setFocusedFirstOption(true);
    } else {
      setFocusedFirstOption(false);
    }
    if ((ev == null ? void 0 : ev.key) === 'Escape') {
      onToggle(ev, {
        isOpen: false
      });
    } else if ((ev == null ? void 0 : ev.key) === 'ArrowUp') {
      focusedFirstOption && setTimeout(function () {
        return inputSearch == null ? void 0 : inputSearch.focus();
      });
    }
  };
  return /*#__PURE__*/_jsxs(_Fragment, {
    children: [/*#__PURE__*/_jsx(MoleculeInputSelect, {
      id: id,
      tags: tags,
      onClick: onToggle,
      tagsCloseIcon: iconCloseTag,
      iconArrowDown: iconArrowDown,
      onChangeTags: handleChangeTags,
      isOpen: isOpen,
      placeholder: !values.length ? placeholder : '',
      optionsData: optionsData,
      autoComplete: "off",
      noBorder: true,
      required: required,
      size: selectSize,
      tabIndex: tabIndex,
      maxTags: maxTags,
      value: "",
      children: /*#__PURE__*/_jsx(MoleculeInputTags, {
        inputMode: inputTypes.NONE
      })
    }), hasSearch && /*#__PURE__*/_jsx(Search, {}), /*#__PURE__*/_jsx(MoleculeDropdownList, {
      checkbox: "true",
      size: size,
      visible: isOpen,
      onSelect: handleMultiSelection,
      onKeyDown: handleKeyDown,
      value: values,
      children: children
    })]
  });
};
MoleculeSelectFieldMultiSelection.displayName = 'MoleculeSelectFieldMultiSelection';
MoleculeSelectFieldMultiSelection.defaultProps = {
  value: []
};
export default MoleculeSelectFieldMultiSelection;

==> react-molecule-select-1.61.0.tgz: package/lib/components/MultipleSelection.js <==
import { useState } from 'react';
import { inputTypes } from '@s-ui/react-atom-input';
import MoleculeDropdownList from '@s-ui/react-molecule-dropdown-list';
import MoleculeInputTags from '@s-ui/react-molecule-input-tags';
import { useDropdown } from '../config.js';
import MoleculeInputSelect from './MoleculeInputSelect.js';
import Search from './Search.js';
import { jsx as _jsx } from "react/jsx-runtime";
import { Fragment as _Fragment } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
var MoleculeSelectFieldMultiSelection = function MoleculeSelectFieldMultiSelection(props) {
  /* eslint-disable react/prop-types */
  var children = props.children,
    isOpen = props.isOpen,
    onToggle = props.onToggle,
    onChange = props.onChange,
    iconArrowDown = props.iconArrowDown,
    iconCloseTag = props.iconCloseTag,
    refMoleculeSelect = props.refMoleculeSelect,
    values = props.value,
    placeholder = props.placeholder,
    keysSelection = props.keysSelection,
    id = props.id,
    size = props.size,
    required = props.required,
    _props$optionsData = props.optionsData,
    optionsData = _props$optionsData === void 0 ? {} : _props$optionsData,
    selectSize = props.selectSize,
    tabIndex = props.tabIndex,
    maxTags = props.maxTags;
  var tags = values.map(function (value) {
    return optionsData[value];
  });
  var _useState = useState(false),
    focusedFirstOption = _useState[0],
    setFocusedFirstOption = _useState[1];
  var _useDropdown = useDropdown(),
    hasSearch = _useDropdown.hasSearch,
    isFirstOptionFocused = _useDropdown.isFirstOptionFocused,
    inputSearch = _useDropdown.inputSearch;
  var handleMultiSelection = function handleMultiSelection(ev, _ref) {
    var valueOptionSelected = _ref.value;
    var handleToggle = function handleToggle(ev) {
      var key = ev.key;
      var isKeySelection = keysSelection.includes(key);
      if (ev.key !== undefined && !isKeySelection) onToggle(ev, {
        isOpen: false
      });
    };
    var isValueSelectedAlreadySelected = function isValueSelectedAlreadySelected() {
      return values.includes(valueOptionSelected);
    };
    var removeFromValues = function removeFromValues() {
      return values.filter(function (value) {
        return value !== valueOptionSelected;
      });
    };
    var addToValues = function addToValues() {
      return [].concat(values, [valueOptionSelected]);
    };
    var isFull = function isFull() {
      return maxTags && (tags == null ? void 0 : tags.length) >= maxTags;
    };
    if (isValueSelectedAlreadySelected()) {
      onChange(ev, {
        value: removeFromValues()
      });
    } else if (!isFull()) {
      onChange(ev, {
        value: addToValues()
      });
    }
    handleToggle(ev);
  };
  var handleChangeTags = function handleChangeTags(ev, _ref2) {
    var value = _ref2.tags;
    onChange(ev, {
      value: value
    });
    refMoleculeSelect.current.focus();
  };
  var handleKeyDown = function handleKeyDown(ev) {
    if (isFirstOptionFocused()) {
      setFocusedFirstOption(true);
    } else {
      setFocusedFirstOption(false);
    }
    if ((ev == null ? void 0 : ev.key) === 'Escape') {
      onToggle(ev, {
        isOpen: false
      });
    } else if ((ev == null ? void 0 : ev.key) === 'ArrowUp') {
      focusedFirstOption && setTimeout(function () {
        return inputSearch == null ? void 0 : inputSearch.focus();
      });
    }
  };
  return /*#__PURE__*/_jsxs(_Fragment, {
    children: [/*#__PURE__*/_jsx(MoleculeInputSelect, {
      id: id,
      tags: tags,
      onClick: onToggle,
      tagsCloseIcon: iconCloseTag,
      iconArrowDown: iconArrowDown,
      onChangeTags: handleChangeTags,
      isOpen: isOpen,
      placeholder: !values.length ? placeholder : '',
      optionsData: optionsData,
      autoComplete: "off",
      noBorder: true,
      required: required,
      size: selectSize,
      tabIndex: tabIndex,
      maxTags: maxTags,
      value: "",
      children: /*#__PURE__*/_jsx(MoleculeInputTags, {
        inputMode: inputTypes.NONE
      })
    }), hasSearch && /*#__PURE__*/_jsx(Search, {}), /*#__PURE__*/_jsx(MoleculeDropdownList, {
      checkbox: "true",
      size: size,
      visible: isOpen,
      onSelect: handleMultiSelection,
      onKeyDown: handleKeyDown,
      value: values,
      children: children
    })]
  });
};
MoleculeSelectFieldMultiSelection.displayName = 'MoleculeSelectFieldMultiSelection';
MoleculeSelectFieldMultiSelection.defaultProps = {
  value: []
};
export default MoleculeSelectFieldMultiSelection;
